# coding: utf-8

"""
    NetSuite REST API

    NetSuite REST Record API generated 2023-01-18 at 19:40:11 UTC for account 472052, user will@theapiguys.com with role Keap Integration.  # noqa: E501

    OpenAPI spec version: v1
    Contact: info@netsuite.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomerItemPricingElement(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[NsLink]',
        'price': 'float',
        'ref_name': 'str',
        'item': 'OneOfcustomerItemPricingElementItem',
        'level': 'NsResource'
    }

    attribute_map = {
        'links': 'links',
        'price': 'price',
        'ref_name': 'refName',
        'item': 'item',
        'level': 'level'
    }

    def __init__(self, links=None, price=None, ref_name=None, item=None, level=None):  # noqa: E501
        """CustomerItemPricingElement - a model defined in Swagger"""  # noqa: E501
        self._links = None
        self._price = None
        self._ref_name = None
        self._item = None
        self._level = None
        self.discriminator = None
        if links is not None:
            self.links = links
        if price is not None:
            self.price = price
        if ref_name is not None:
            self.ref_name = ref_name
        if item is not None:
            self.item = item
        if level is not None:
            self.level = level

    @property
    def links(self):
        """Gets the links of this CustomerItemPricingElement.  # noqa: E501


        :return: The links of this CustomerItemPricingElement.  # noqa: E501
        :rtype: list[NsLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this CustomerItemPricingElement.


        :param links: The links of this CustomerItemPricingElement.  # noqa: E501
        :type: list[NsLink]
        """

        self._links = links

    @property
    def price(self):
        """Gets the price of this CustomerItemPricingElement.  # noqa: E501


        :return: The price of this CustomerItemPricingElement.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this CustomerItemPricingElement.


        :param price: The price of this CustomerItemPricingElement.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def ref_name(self):
        """Gets the ref_name of this CustomerItemPricingElement.  # noqa: E501


        :return: The ref_name of this CustomerItemPricingElement.  # noqa: E501
        :rtype: str
        """
        return self._ref_name

    @ref_name.setter
    def ref_name(self, ref_name):
        """Sets the ref_name of this CustomerItemPricingElement.


        :param ref_name: The ref_name of this CustomerItemPricingElement.  # noqa: E501
        :type: str
        """

        self._ref_name = ref_name

    @property
    def item(self):
        """Gets the item of this CustomerItemPricingElement.  # noqa: E501


        :return: The item of this CustomerItemPricingElement.  # noqa: E501
        :rtype: OneOfcustomerItemPricingElementItem
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this CustomerItemPricingElement.


        :param item: The item of this CustomerItemPricingElement.  # noqa: E501
        :type: OneOfcustomerItemPricingElementItem
        """

        self._item = item

    @property
    def level(self):
        """Gets the level of this CustomerItemPricingElement.  # noqa: E501


        :return: The level of this CustomerItemPricingElement.  # noqa: E501
        :rtype: NsResource
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this CustomerItemPricingElement.


        :param level: The level of this CustomerItemPricingElement.  # noqa: E501
        :type: NsResource
        """

        self._level = level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomerItemPricingElement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomerItemPricingElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
