# coding: utf-8

"""
    NetSuite REST API

    NetSuite REST Record API generated 2023-01-18 at 19:40:11 UTC for account 472052, user will@theapiguys.com with role Keap Integration.  # noqa: E501

    OpenAPI spec version: v1
    Contact: info@netsuite.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NsErrorOerrorDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'detail': 'str',
        'oerror_path': 'str',
        'oerror_url': 'str',
        'oerror_header': 'str',
        'oerror_query_param': 'str',
        'oerror_code': 'str'
    }

    attribute_map = {
        'detail': 'detail',
        'oerror_path': 'o:errorPath',
        'oerror_url': 'o:errorUrl',
        'oerror_header': 'o:errorHeader',
        'oerror_query_param': 'o:errorQueryParam',
        'oerror_code': 'o:errorCode'
    }

    def __init__(self, detail=None, oerror_path=None, oerror_url=None, oerror_header=None, oerror_query_param=None, oerror_code=None):  # noqa: E501
        """NsErrorOerrorDetails - a model defined in Swagger"""  # noqa: E501
        self._detail = None
        self._oerror_path = None
        self._oerror_url = None
        self._oerror_header = None
        self._oerror_query_param = None
        self._oerror_code = None
        self.discriminator = None
        if detail is not None:
            self.detail = detail
        if oerror_path is not None:
            self.oerror_path = oerror_path
        if oerror_url is not None:
            self.oerror_url = oerror_url
        if oerror_header is not None:
            self.oerror_header = oerror_header
        if oerror_query_param is not None:
            self.oerror_query_param = oerror_query_param
        if oerror_code is not None:
            self.oerror_code = oerror_code

    @property
    def detail(self):
        """Gets the detail of this NsErrorOerrorDetails.  # noqa: E501

        A detailed, human-readable description of the problem occurrence.  # noqa: E501

        :return: The detail of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this NsErrorOerrorDetails.

        A detailed, human-readable description of the problem occurrence.  # noqa: E501

        :param detail: The detail of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._detail = detail

    @property
    def oerror_path(self):
        """Gets the oerror_path of this NsErrorOerrorDetails.  # noqa: E501

        The JSON path that indicates where the problem occurs within the request body.  # noqa: E501

        :return: The oerror_path of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_path

    @oerror_path.setter
    def oerror_path(self, oerror_path):
        """Sets the oerror_path of this NsErrorOerrorDetails.

        The JSON path that indicates where the problem occurs within the request body.  # noqa: E501

        :param oerror_path: The oerror_path of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_path = oerror_path

    @property
    def oerror_url(self):
        """Gets the oerror_url of this NsErrorOerrorDetails.  # noqa: E501

        The URI of the first element in the request URL where the problem occurs.  # noqa: E501

        :return: The oerror_url of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_url

    @oerror_url.setter
    def oerror_url(self, oerror_url):
        """Sets the oerror_url of this NsErrorOerrorDetails.

        The URI of the first element in the request URL where the problem occurs.  # noqa: E501

        :param oerror_url: The oerror_url of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_url = oerror_url

    @property
    def oerror_header(self):
        """Gets the oerror_header of this NsErrorOerrorDetails.  # noqa: E501

        The name of the HTTP header where the problem occurs.  # noqa: E501

        :return: The oerror_header of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_header

    @oerror_header.setter
    def oerror_header(self, oerror_header):
        """Sets the oerror_header of this NsErrorOerrorDetails.

        The name of the HTTP header where the problem occurs.  # noqa: E501

        :param oerror_header: The oerror_header of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_header = oerror_header

    @property
    def oerror_query_param(self):
        """Gets the oerror_query_param of this NsErrorOerrorDetails.  # noqa: E501

        The name of the query parameter where the problem occurs.  # noqa: E501

        :return: The oerror_query_param of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_query_param

    @oerror_query_param.setter
    def oerror_query_param(self, oerror_query_param):
        """Sets the oerror_query_param of this NsErrorOerrorDetails.

        The name of the query parameter where the problem occurs.  # noqa: E501

        :param oerror_query_param: The oerror_query_param of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_query_param = oerror_query_param

    @property
    def oerror_code(self):
        """Gets the oerror_code of this NsErrorOerrorDetails.  # noqa: E501

        The application-specific error code. Similar problem types are grouped together.  # noqa: E501

        :return: The oerror_code of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_code

    @oerror_code.setter
    def oerror_code(self, oerror_code):
        """Sets the oerror_code of this NsErrorOerrorDetails.

        The application-specific error code. Similar problem types are grouped together.  # noqa: E501

        :param oerror_code: The oerror_code of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_code = oerror_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NsErrorOerrorDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NsErrorOerrorDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
